*=================== Program: PQI09_ALL_MEASURES.SAS ========================================;
*
*  Description:
*         ASSIGNS THE PEDIATRIC QUALITY OUTCOME MEASURE OF INTEREST, STRATIFIERS, AND
*         COMORBIDITY FLAGS TO INPATIENT RECORDS
*         VARIABLES CREATED BY THIS PROGRAM ARE TPPQ09,QPPQ09,PPPQ09,TAPQ09,
*         STRATIFIERS AND COMORBIDITIES;
*
*         AHRQ QI VERSION V6.0.2 ICD-09-CM
*         VERSION DATE AUGUST 2017
*
*  USER NOTE1: Make sure you have created the format library
*              using PDI_FORMATS.SAS BEFORE running this program.
*
*  USER NOTE2: The AHRQ QI software does not support the calculation of weighted 
*            estimates and standard errors using complex sampling designs. 
*
*  USER NOTE3: See the AHRQ_QI_ICD09_v6_Release_Notes.txt file for software change notes.
*================================================================================;

filename CONTROL "c:\Pathname\PQI_09\Programs\PQI09_ALL_CONTROL.SAS";          *<==USER MUST modify;

%include CONTROL;

title2 'PQI09_ALL_MEASURES PROGRAM';
title3 'AHRQ PATIENT SAFETY INDICATORS: ASSIGN QIS TO INPATIENT DATA';

 * -------------------------------------------------------------- ;
 * --- CREATE A PERMANENT DATASET CONTAINING ALL RECORDS THAT --- ; 
 * --- WILL NOT BE INCLUDED IN ANALYSIS BECAUSE KEY VARIABLE  --- ;
 * --- VALUES ARE MISSING                                     --- ;
 * -------------------------------------------------------------- ;

 data   OUTMSR.&DELFILE1.
     (keep=KEY HOSPID SEX AGE DX1 MDC YEAR DQTR);
 set INMSR.&DISCHARGE.;
     if (AGE lt 0) or (AGE ge 18 or MDC in (14)) or (SEX le 0) or 
    (DX1 in (' ')) or (DQTR le .Z) or (YEAR le .Z);
 run;

 * -------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATOR (PDI) NAMING CONVENTION:   --- ;
 * --- THE FIRST LETTER IDENTIFIES THE PEDIATRIC INDICATOR    --- ;
 * --- INDICATOR AS ONE OF THE FOLLOWING:
                (T) NUMERATOR ("TOP")
                (P) POPULATION ("POP")
                (Q) EXCLUSION FLAG BASED ON POA
 * --- THE SECOND LETTER IDENTIFIES THE PDI AS A PROVIDER (P) --- ;
 * --- OR AN AREA (A) LEVEL INDICATOR.  THE                   --- ;
 * --- NEXT TWO CHARACTERS ARE ALWAYS 'PD'. THE LAST TWO      --- ;
 * --- DIGITS ARE THE INDICATOR NUMBER (WITHIN THAT SUBTYPE). --- ;
 * -------------------------------------------------------------- ;

 %MACRO ADDPRDAY; 
    %IF &PRDAY EQ 1 %THEN PRDAY1-PRDAY&NPR. ;
 %MEND;

 data   OUTMSR.&OUTFILE_MEAS. 
    (keep=KEY HOSPID FIPST FIPSTCO DRG DRGVER MDC MDRG YEAR DQTR AGE AGEDAY SEX
          PAGECAT AGEDCAT POPCAT BWHTCAT SEXCAT CONGCAT RACECAT PAYCAT DUALCAT
          LOS TRNSFER TAPQ09);

 set   INMSR.&DISCHARGE. 
      (keep=KEY HOSPID DRG DRGVER MDC SEX AGE AGEDAY PSTCO 
            RACE YEAR DQTR PAY1 PAY2 DNR
            DISP LOS ASOURCE POINTOFORIGINUB04 ATYPE
            DX1-DX&NDX. PR1-PR&NPR. %ADDPRDAY 
            DXPOA1-DXPOA&NDX.);

 *** Load standard diagnosis and procedure macros ;
 %include Maclib(PQI09_Dx_Px_Macros.sas) ;

  * -------------------------------------------------------------- ;
 * --- DELETE NON-PEDIATRIC RECORDS AND RECORDS W MISSING VALUES  ;
 * -------------------------------------------------------------- ;
 if SEX le 0 then delete;
 if AGE lt 0 then delete;
 if AGE ge 18 or MDC in (14) then delete;
 if DX1 in (' ') then delete;
 if DQTR le .Z then delete;
 if YEAR le .Z then delete;

 * -------------------------------------------------------------- ;
 * --- DEFINE MDC                        ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib MDCNEW length=3 label='IMPUTED MDC';

 if DRGVER le .Z then do;
         if (YEAR in (2007) and DQTR in (4))     then DRGVER = 25;
    else if (YEAR in (2008) and DQTR in (1,2,3)) then DRGVER = 25;
    else if (YEAR in (2008) and DQTR in (4))     then DRGVER = 26;
    else if (YEAR in (2009) and DQTR in (1,2,3)) then DRGVER = 26;
    else if (YEAR in (2009) and DQTR in (4))     then DRGVER = 27;
    else if (YEAR in (2010) and DQTR in (1,2,3)) then DRGVER = 27;
    else if (YEAR in (2010) and DQTR in (4))     then DRGVER = 28;
    else if (YEAR in (2011) and DQTR in (1,2,3)) then DRGVER = 28;
    else if (YEAR in (2011) and DQTR in (4))     then DRGVER = 29;
    else if (YEAR in (2012) and DQTR in (1,2,3)) then DRGVER = 29;
    else if (YEAR in (2012) and DQTR in (4))     then DRGVER = 30;
    else if (YEAR in (2013) and DQTR in (1,2,3)) then DRGVER = 30;
    else if (YEAR in (2013) and DQTR in (4))     then DRGVER = 31;
    else if (YEAR in (2014) and DQTR in (1,2,3)) then DRGVER = 31;
    else if (YEAR in (2014) and DQTR in (4))     then DRGVER = 32;
    else if (YEAR in (2015) and DQTR in (1,2,3)) then DRGVER = 32;
 end;

  *------------------- IMPUTE MDC 24 ---------------------* ;
 *-- Define arrays to be used in defining MDC24 below. --* ;
 *-- Eight different body sites are defined:           --* ;
 *-------------------------------------------------------* ;
 *--    1: head                                        --* ;
 *--    2: chest                                       --* ;
 *--    3: abdominal                                   --* ;
 *--    4: kidney                                      --* ;
 *--    5: urinary                                     --* ;
 *--    6: pelvis/spine                                --* ;
 *--    7: upper limb                                  --* ;
 *--    8: lower limb                                  --* ; 
 *-------------------------------------------------------* ;

 array site_dx(&ndx.) $ site_dx1-site_dx&ndx.;

 %defsite;

 if put(dx1,$pr.)='1' then trauma_dx1=1; else trauma_dx1=0;

 if (1<=DRG<=8 OR 10 <=DRG <=14 OR DRG IN (16,17) OR 981<=DRG<=989) then do;
    
    *The duplicated DX1 are all mapped to 12 in the format $DX1MDC, so correct them here based on SEX;
    
    if DX1 IN ("05410", "05419", "0910",  "0980",  "09810", "09819", "0982",  "09839", "0990", "0991",
               "0992 ", "09940", "09941", "09949", "09950", "09953", "09955", "09959", "0998", "0999",
               "1122",  "13100", "13102", "13109", "1953",  "19882", "4565",  "6981",  "7527", "75289",
               "7529",  "7586",  "75881", "75889", "8676",  "8677",  "8678",  "8679",  "8788", "8789",
               "9082",  "9224",  "9260",  "V252",  "V260",  "V4577") then do;
               if sex=1 then MDC=12;
          else if sex=2 then MDC=13;
    end;
    else MDC=PUT(DX1,$DX1MDC.);

    * MDC 24 requires the review of multiple diagnoses;

    if (981 <=DRG <= 989) then do;
    Flag_TwoSitesInDXs=0;
    do i = 2 to &ndx.;
       do j = (i+1) to &ndx.;
          if site_dx(i)^=' ' and site_dx(j)^=' ' and  site_dx(i)^=site_dx(j) then Flag_TwoSitesInDXs=Flag_TwoSitesInDXs+1;
       end;
    end;

    if trauma_dx1=1 then do;
      if (%mdx1($s1fmt.) and (%mdx2($s2fmt.) or %mdx2($s3fmt.) or %mdx2($s4fmt.) or %mdx2($s5fmt.) or %mdx2($s6fmt.) or %mdx2($s7fmt.) or %mdx2($s8fmt.))) or 
         (%mdx1($s2fmt.) and (%mdx2($s1fmt.) or %mdx2($s3fmt.) or %mdx2($s4fmt.) or %mdx2($s5fmt.) or %mdx2($s6fmt.) or %mdx2($s7fmt.) or %mdx2($s8fmt.))) or 
         (%mdx1($s3fmt.) and (%mdx2($s1fmt.) or %mdx2($s2fmt.) or %mdx2($s4fmt.) or %mdx2($s5fmt.) or %mdx2($s6fmt.) or %mdx2($s7fmt.) or %mdx2($s8fmt.))) or 
         (%mdx1($s4fmt.) and (%mdx2($s1fmt.) or %mdx2($s2fmt.) or %mdx2($s3fmt.) or %mdx2($s5fmt.) or %mdx2($s6fmt.) or %mdx2($s7fmt.) or %mdx2($s8fmt.))) or 
         (%mdx1($s5fmt.) and (%mdx2($s1fmt.) or %mdx2($s2fmt.) or %mdx2($s3fmt.) or %mdx2($s4fmt.) or %mdx2($s6fmt.) or %mdx2($s7fmt.) or %mdx2($s8fmt.))) or 
         (%mdx1($s6fmt.) and (%mdx2($s1fmt.) or %mdx2($s2fmt.) or %mdx2($s3fmt.) or %mdx2($s4fmt.) or %mdx2($s5fmt.) or %mdx2($s7fmt.) or %mdx2($s8fmt.))) or 
         (%mdx1($s7fmt.) and (%mdx2($s1fmt.) or %mdx2($s2fmt.) or %mdx2($s3fmt.) or %mdx2($s4fmt.) or %mdx2($s5fmt.) or %mdx2($s6fmt.) or %mdx2($s8fmt.))) or 
         (%mdx1($s8fmt.) and (%mdx2($s1fmt.) or %mdx2($s2fmt.) or %mdx2($s3fmt.) or %mdx2($s4fmt.) or %mdx2($s5fmt.) or %mdx2($s6fmt.) or %mdx2($s7fmt.))) or 
         (put(DX1,$s1fmt.)='0' and 
          put(DX1,$s2fmt.)='0' and 
          put(DX1,$s3fmt.)='0' and 
          put(DX1,$s4fmt.)='0' and 
          put(DX1,$s5fmt.)='0' and 
          put(DX1,$s6fmt.)='0' and 
          put(DX1,$s7fmt.)='0' and 
          put(DX1,$s8fmt.)='0' and Flag_TwoSitesInDXs>0) then MDC=24;
    end;
    end;
 end;

 *** Apply Standard MDC mappings ;
 if MDC notin (01,02,03,04,05,06,07,08,09,10,
               11,12,13,14,15,16,17,18,19,20,
               21,22,23,24,25)
 then do;
    MDCNEW = put(DRG,MDCF2T.);
    if MDCNEW in (01,02,03,04,05,06,07,08,09,10,
                  11,12,13,14,15,16,17,18,19,20,
                  21,22,23,24,25)
    then MDC=MDCNEW;
    else do;
       if DRG in (999) then MDC = 0;
       else put "INVALID MDC KEY: " KEY " MDC " MDC " DRG " DRG DRGVER;
    end;
 end;

 * -------------------------------------------------------------- ;
 * --- COUNT THE NUMBER OF PR CODES                     --------- ;
 * -------------------------------------------------------------- ;
 array ARRY6{&NPR.} PRDAY1-PRDAY&NPR.;

 MAXPR = 0; CNTPRDAY = 0;
 do I = 1 TO &NPR.;
    if ARRY6(I) ge 0 then CNTPRDAY + 1;
 end;

 if &PRDAY. EQ 0 or CNTPRDAY = 0 then NOPRDAY = 1;
 else NOPRDAY = 0;

 * -------------------------------------------------------------- ;
 * --- DEFINE FIPS STATE AND COUNTY CODES             ----------- ;
 * -------------------------------------------------------------- ;
 attrib FIPSTCO length=$5 label='FIPS STATE COUNTY CODE';
 FIPSTCO = put(PSTCO,Z5.);

 attrib FIPST length=$2 label='STATE FIPS CODE';
 FIPST = SUBSTR(FIPSTCO,1,2);

 * -------------------------------------------------------------- ;
 * --- DEFINE ICD-9-CM VERSION           ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib ICDVER length=3 label='ICD-9-CM VERSION';

 ICDVER = 0;
      if (YEAR in (2007) and DQTR in (4))     then ICDVER = 25;
 else if (YEAR in (2008) and DQTR in (1,2,3)) then ICDVER = 25;
 else if (YEAR in (2008) and DQTR in (4))     then ICDVER = 26;
 else if (YEAR in (2009) and DQTR in (1,2,3)) then ICDVER = 26;
 else if (YEAR in (2009) and DQTR in (4))       then ICDVER = 27;
 else if (YEAR in (2010) and DQTR in (1,2,3)) then ICDVER = 27;
 else if (YEAR in (2010) and DQTR in (4))     then ICDVER = 28;
 else if (YEAR in (2011) and DQTR in (1,2,3)) then ICDVER = 28;
 else if (YEAR in (2011) and DQTR in (4))     then ICDVER = 29;
 else if (YEAR in (2012) and DQTR in (1,2,3)) then ICDVER = 29;
 else if (YEAR in (2012) and DQTR in (4))     then ICDVER = 30;
 else if (YEAR in (2013) and DQTR in (1,2,3)) then ICDVER = 30;
 else if (YEAR in (2013) and DQTR in (4))     then ICDVER = 31;
 else if (YEAR in (2014) and DQTR in (1,2,3)) then ICDVER = 31;
 else if (YEAR in (2014) and DQTR in (4))     then ICDVER = 32;
 else if (YEAR in (2015) and DQTR in (1,2,3)) then ICDVER = 32;

 * -------------------------------------------------------------- ;
 * --- DEFINE MEDICAL DRGS               ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib MEDICDR length=3 label='MEDICAL DRGS';

 if %MDR($MEDIC2R.) then MEDICDR = 1;
 else MEDICDR = 0;

 * -------------------------------------------------------------- ;
 * --- DEFINE SURGICAL DRGS              ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib SURGIDR length=3 label='SURGICAL DRGS';

 if %MDR($SURGI2R.) then SURGIDR = 1;
 else SURGIDR = 0;

 * -------------------------------------------------------------- ;
 * --- DEFINE MODIFIED DRGS              ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib MDRG length=4 label='MODIFIED DRG';

 MDRG = put(put(DRG,Z3.),$DRGF2T.);

 * -------------------------------------------------------------- ;
 * --- DEFINE INFECTION RISK CATEGORIES  ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib DRG1C length=3 label='CLEAN';
 attrib DRG2C length=3 label='CLEAN CONTAMINATED';
 attrib DRG3C length=3 label='POTENTIALLY CONTAMINATED';
 attrib DRG4C length=3 label='LIKELY INFECTED';
 attrib DRG9C length=3 label='SURGICAL PROCEDURES NOT SPECIFIED';

 DRG1C = put(MDRG,DRG1C.);
 DRG2C = put(MDRG,DRG2C.);
 DRG3C = put(MDRG,DRG3C.);
 DRG4C = put(MDRG,DRG4C.);
 DRG9C = put(MDRG,DRG9C.);

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: PAYER CATEGORY ------------------------ ;
 * -------------------------------------------------------------- ;
 attrib PAYCAT length=3 label='PATIENT PRIMARY PAYER';

 select (PAY1);
   when (1)  PAYCAT = 1;
   when (2)  PAYCAT = 2;
   when (3)  PAYCAT = 3;
   when (4)  PAYCAT = 4;
   when (5)  PAYCAT = 5;
   otherwise PAYCAT = 6;
 end; * SELECT PAY1 ;

 attrib DUALCAT length=3 label='PATIENT DUAL ELIGIBLE';

 if (PAY1 in (1) and PAY2 in (2)) or
    (PAY1 in (2) and PAY2 in (1)) 
 then DUALCAT = 1; else DUALCAT = 0;
    
 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: RACE CATEGORY ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib RACECAT length=3 label='PATIENT RACE/ETHNICITY';

 select (RACE);
   when (1)  RACECAT = 1;
   when (2)  RACECAT = 2;
   when (3)  RACECAT = 3;
   when (4)  RACECAT = 4;
   when (5)  RACECAT = 5;
   otherwise RACECAT = 6;
 end; * SELECT RACE ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGE CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib PAGECAT length=3 label='PATIENT AGE';

 select;
   when (0  <= AGE <  1)  PAGECAT = 1;
   when (1  <= AGE <  3)  PAGECAT = 2;
   when (3  <= AGE <  6)  PAGECAT = 3;
   when (6  <= AGE < 13)  PAGECAT = 4;
   when (13 <= AGE < 18)  PAGECAT = 5;
   otherwise PAGECAT = 0;
 end; * SELECT AGE ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: AGEDAY CATEGORY  ---------------------- ;
 * -------------------------------------------------------------- ;
 attrib AGEDCAT length=3 label='PATIENT AGE IN DAYS';

 select;
   when (      AGEDAY <   0)  AGEDCAT = 0;
   when (0  <= AGEDAY <= 28)  AGEDCAT = 1;
   when (29 <= AGEDAY <= 60)  AGEDCAT = 2;
   when (61 <= AGEDAY <= 90)  AGEDCAT = 3;
   when (91 <= AGEDAY      )  AGEDCAT = 4;
   otherwise AGEDCAT = 0;
 end; * SELECT AGEDAY ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: SEX CATEGORY  ------------------------- ;
 * -------------------------------------------------------------- ;
 attrib SEXCAT length=3 label='PATIENT GENDER';

 select (SEX);
   when (1)  SEXCAT = 1;
   when (2)  SEXCAT = 2;
   otherwise SEXCAT = 0;
 end; * SELECT SEX ;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: POPULATION CATEGORY ------------------- ;
 * -------------------------------------------------------------- ;
 attrib POPCAT length=3 label='PATIENT AGE';

 POPCAT=put(AGE,AGEFMT.);

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: BIRTH WEIGHT CATEGORY  ---------------- ;
 * -------------------------------------------------------------- ;
 attrib BWHTCAT length=3 label='PATIENT BIRTHWEIGHT';

 %MACRO BWHT;

 BWHTCAT = 0;
 %DO I = 1 %TO &NDX.;
    if put(DX&I.,$LW500G.)  = '1'      then BWHTCAT = 1;
    else if put(DX&I.,$LW750G.)  = '1' and (BWHTCAT = 0 or  BWHTCAT > 2) then BWHTCAT = 2;
    else if put(DX&I.,$LW1000G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 3) then BWHTCAT = 3;
    else if put(DX&I.,$LW1250G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 4) then BWHTCAT = 4;
    else if put(DX&I.,$LW1500G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 5) then BWHTCAT = 5;
    else if put(DX&I.,$LW1750G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 6) then BWHTCAT = 6;
    else if put(DX&I.,$LW2000G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 7) then BWHTCAT = 7;
    else if put(DX&I.,$LW2500G.) = '1' and (BWHTCAT = 0 or  BWHTCAT > 8) then BWHTCAT = 8;
    else if put(DX&I.,$LW2500P.) = '1' and (BWHTCAT = 0) then BWHTCAT = 9;
 %END;
 
 %MEND;

 %BWHT;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: GESTATIONAL AGE CATEGORY -------------- ;
 * -------------------------------------------------------------- ;
 attrib GESTCAT length=3 label='PATIENT GESTATIONAL AGE';

 %MACRO GEST;

 GESTCAT = 0;
 %DO I = 1 %TO &NDX.;
    if put(DX&I.,$GESTC1D.)  = '1'     then GESTCAT = 1;
    else if put(DX&I.,$GESTC2D.) = '1' and (GESTCAT = 0 or GESTCAT > 2) then GESTCAT = 2;
    else if put(DX&I.,$GESTC3D.) = '1' and (GESTCAT = 0 or GESTCAT > 3) then GESTCAT = 3;
    else if put(DX&I.,$GESTC4D.) = '1' and (GESTCAT = 0 or GESTCAT > 4) then GESTCAT = 4;
    else if put(DX&I.,$GESTC5D.) = '1' and (GESTCAT = 0 or GESTCAT > 5) then GESTCAT = 5;
    else if put(DX&I.,$GESTC6D.) = '1' and (GESTCAT = 0 or GESTCAT > 6) then GESTCAT = 6;
    else if put(DX&I.,$GESTC7D.) = '1' and (GESTCAT = 0 or GESTCAT > 7) then GESTCAT = 7;
    else if put(DX&I.,$GESTC8D.) = '1' and (GESTCAT = 0 or GESTCAT > 8) then GESTCAT = 8;
    else if put(DX&I.,$GESTC9D.) = '1' and (GESTCAT = 0) then GESTCAT = 9;
 %END;
 
 %MEND;

 %GEST;

 * -------------------------------------------------------------- ;
 * --- DEFINE STRATIFIER: CONGENITAL ANAMOLY     ---------------- ;
 * -------------------------------------------------------------- ;
 attrib CONGCAT length=3 label='CONGENITAL ANAMOLY';

 %MACRO CONG;
 CONGCAT = 0;
 %DO I = 1 %TO &NDX.;
    if put(DX&I.,$CONGN1D.)  = '1'     then CONGCAT = 1;
    else if put(DX&I.,$CONGN2D.) = '1' and (CONGCAT = 0 or CONGCAT > 2) then CONGCAT = 2;
    else if put(DX&I.,$CONGN3D.) = '1' and (CONGCAT = 0 or CONGCAT > 3) then CONGCAT = 3;
    else if put(DX&I.,$CONGN4D.) = '1' and (CONGCAT = 0 or CONGCAT > 4) then CONGCAT = 4;
    else if put(DX&I.,$CONGN5D.) = '1' and (CONGCAT = 0 or CONGCAT > 5) then CONGCAT = 5;
    else if put(DX&I.,$CONGN6D.) = '1' and (CONGCAT = 0 or CONGCAT > 6) then CONGCAT = 6;
    else if put(DX&I.,$CONGN7D.) = '1' and (CONGCAT = 0 or CONGCAT > 7) then CONGCAT = 7;
    else if put(DX&I.,$CONGN8D.) = '1' and (CONGCAT = 0) then CONGCAT = 8;
 %END;

 %MEND;

 %CONG;

 attrib MULTIBTH length=3 label='MULTIPLE BIRTHS';

 MULTIBTH=%MDX($MULTIPD.);

 * -------------------------------------------------------------- ;
 * --- COUNT OR PROCEDURES AND IDENTIFY FIRST OR PROCEDURE ------ ;
 * -------------------------------------------------------------- ;
 attrib ORCNT length=8 label='OR PROCEDURE COUNT';
 attrib ORDAY length=8 label='OR PROCEDURE DAY';

 %ORCNT;

 * -------------------------------------------------------------- ;
 * --- DEFINE PROCEDURE TYPE ------------------------------------ ;
 * -------------------------------------------------------------- ;

 %PRCLASS;

 *** Create IMMUNE flag for risk adjustment ;
 if %MDX($IMMUNID.) or %MPR($IMMUNIP.) then IMMUNE=1 ;
 else IMMUNE=0 ;

 * -------------------------------------------------------------- ;
 * --- DEFINE AREA LEVEL INDICATORS ----------------------------- ;
 * -------------------------------------------------------------- ;
 %MACRO LBL;
 
 attrib TAPQ09 length=8 label='PQI 09 Low Birth Weight Rate (Numerator)';

 %MEND;

 %LBL;

 * -------------------------------------------------------------- ;
 * --- IDENTIFY NEONATES AND NEWBORNS --------------------------- ;
 * -------------------------------------------------------------- ;

 NEONATE = 0;
 if 0 <= AGEDAY <= 28 then NEONATE = 1;
 else if AGEDAY le .Z and AGE = 0 then do;
    if ATYPE in (4) or %MDX($V29D.) or %MDX($LIVEBND.)
    then NEONATE = 1;
 end;

 NEWBORN = 0;
 if NEONATE then do;
    if %MDX($LIVEBND.) and NOT AGEDAY > 0 then NEWBORN = 1;
    else if ATYPE in (4) and 
            ((AGEDAY = 0 and NOT %MDX($LIVEB2D.)) or
             POINTOFORIGINUB04 in ('5'))
    then NEWBORN = 1;
 end;
 
 NORMAL = 0;
 if NEWBORN and (DRG in (795))
 then NORMAL = 1;

 OUTBORN = 0;
 if NEONATE and NOT NEWBORN then do;
    if (0 <= AGEDAY < 2) or 
       (ATYPE in (4) and 
        (AGEDAY le .Z or POINTOFORIGINUB04 in ('6'))) 
    then OUTBORN = 1;
 end;

 * -------------------------------------------------- ;
 * --- PQI 09 : LOW BIRTH WEIGHT                  --- ;
 * -------------------------------------------------- ;

 if NEWBORN then do;

    TAPQ09 = 0;

    if %MDX($ACSLBWD.) then TAPQ09 = 1;

 end;

 * -------------------------------------------------------------- ;
 * --- IDENTIFY TRANSFERS --------------------------------------- ;
 * -------------------------------------------------------------- ;

 *** TRANSFER FROM ANOTHER ACUTE ;
 if ATYPE notin (4) and
    (ASOURCE in (2) or POINTOFORIGINUB04 in ('4'))
 then TRNSFER = 1;
 else TRNSFER = 0;
 if ASOURCE GT .Z and POINTOFORIGINUB04 in (' ') then NOPOUB04 = 1;
 else NOPOUB04 = 0;

 *** TRANSFER TO ANOTHER ACUTE ;

 if DISP in (2) then TRNSOUT = 1;else TRNSOUT = 0;

 * -------------------------------------------------------------- ;
 * --- EXCLUDE TRANSFERS ---------------------------------------- ;
 * -------------------------------------------------------------- ;

 *** TRANSFER FROM ANOTHER ;
 if ATYPE notin (4) and
    (ASOURCE in (2,3) or POINTOFORIGINUB04 in ('4','5','6')) 
 then do;
   TAPQ09 = .;
 end;

 * -------------------------------------------------------------- ;
 * --- LABELS --------------------------------------------------- ;
 * -------------------------------------------------------------- ;

 label
    TRNSFER  = 'TRANSFER FROM ACUTE'
;

run;


proc CONTENTS data=OUTMSR.&OUTFILE_MEAS. position;
run;

proc Print data=OUTMSR.&OUTFILE_MEAS. (OBS=24);
title4 "FIRST 24 RECORDS IN OUTPUT DATA SET &OUTFILE_MEAS.";
run;

***----- TO PRINT VARIABLE LABLES COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;

proc Means data = OUTMSR.&OUTFILE_MEAS. n nmiss min max  nolabels  ;
     var KEY DRG DRGVER MDC MDRG YEAR DQTR 
         AGEDCAT PAGECAT POPCAT BWHTCAT SEXCAT CONGCAT RACECAT PAYCAT DUALCAT 
         LOS TRNSFER ;
     title4  "CATEGORICAL VARIABLES AND RANGES OF VALUES";
run; quit;

proc Means data = OUTMSR.&OUTFILE_MEAS. n nmiss sum  nolabels  ;
     var TAPQ09;
     title "PEDIATRIC INDICATOR NUMERATORS FOR AREA-BASED OR COUNT BASED INDICATORS (COUNT =SUM)";
run; quit;

