*============== Program : PQI09_AREA_OBSERVED.SAS ====================;
*
*        Title:  AREA LEVEL OBSERVED RATES FOR AHRQ 
*                PEDIATRIC QUALITY INDICATOR 09
*  Description:
*         USES PROC SUMMARY TO CALCULATE OBSERVED RATES FOR
*         PATIENT SAFETY INDICATORS ACROSS STRATIFIERS.
*         OUTPUT STRATIFIED BY AREA, AGECAT, SEXCAT AND RACECAT FROM 
*         POPULATION FILE AND PDI_MEASURE OUTPUT.
*         VARIABLES CREATED BY THIS PROGRAM ARE PAPDxx AND OAPDxx
*
*         AHRQ QI VERSION V6.0.2 ICD-09-CM
*         VERSION DATE AUGUST 2017
*===================================================================;
* See the AHRQ_QI_ICD09_v6_Release_Notes.txt file for version change details.;

filename CONTROL "c:\pathname\PQI_09\Programs\PQI09_ALL_CONTROL.SAS";          *<==USER MUST modify;
%include CONTROL;

 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        attrib MAREA length=$5
          label='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        attrib MAREA length=$5
          label='MODIFIED FIPS';
        MAREA = input(put(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 1999 METRO AREA';
        MAREA = input(put(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 2003 METRO AREA';
        MAREA = input(put(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 title2 'PROGRAM PQI09_AREA_1 PART I';
 title3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE ADJUSTED AREA RATES';

 * ---------------------------------------------------------------- ;
 * --- ADD POPULATION DENOMINATOR --------------------------------- ;
 * --- THIS STEP DETERMINES WHICH AREAS ARE INCLUDED IN THE     --- ;
 * --- OUTPUT FROM PROGRAM PDI_AREA_OBSERVED.                   --- ;
 * ---------------------------------------------------------------- ;

 data   TEMP0;
 set    OUTMSR.&OUTFILE_MEAS.;

 %CTY2MA

 run;

 proc   Sort data=TEMP0 (keep=MAREA) out=MAREA nodupkey;
 by     MAREA;
 run;

 data QIPOP0;
    length FIPSTCO $5 SEXCAT POPCAT RACECAT 3 
           POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
           POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
           POP_2005 POP_2006 POP_2007 POP_2008 POP_2009 
           POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
           POP_2015 POP 8;

    infile POPFILE missover firstobs=2;

   input FIPSTCO SEXCAT POPCAT RACECAT 
          POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
          POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
          POP_2005 POP_2006 POP_2007 POP_2008 POP_2009
          POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
          POP_2015;

    %CTY2MA

    POP = POP_&POPYEAR.;

    if POPCAT in (1,2,3,4);

 run;

 proc   Summary data=QIPOP0 nway ;           
 class  MAREA POPCAT SEXCAT RACECAT;
 var    POP;
 output out=QIPOP sum=;
 run;

 proc   Sort data=QIPOP;
 by     MAREA POPCAT SEXCAT RACECAT;
 run;

 data   QIPOP(keep=MAREA POPCAT SEXCAT RACECAT POP);
 merge  MAREA(in=X) QIPOP(in=Y);
 by     MAREA;

 if X and Y;

 run;

 * ----------------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATORS ADJUSTED RATES ----------------------- ;
 * ----------------------------------------------------------------------- ;
 * --- THIS STEP SELECTS THE OBSERVATIONS FROM THE PQI09_AREA_OBSERVED --- ;
 * --- PROGRAM OUTPUT FOR EACH PEDIATRIC QUALITY INDICATOR IN TURN.    --- ;
 * --- EACH ITERATION PASSES VARIABLES THAT CONTROL THE                --- ;
 * --- COVARIATES FOR THAT PEDIATRIC QUALITY INDICATOR:                --- ;
 * --- N - OBSERVATION NUMBER FROM THE MEANS AND COVAR FILES           --- ;
 * ---     ALSO IDENTIFIES THE FORMAT USED TO INDEX COVARIATES         --- ;
 * --- PD - THE PEDIATRIC QUALITY INDICATOR NAME WITHOUT THE           --- ;
 *          PREFIX (A)                                                 --- ;
 * ----------------------------------------------------------------------- ;

 %MACRO MOD3(PD);

 * --- THIS SET CREATES TEMP1 WHICH CONTAINS THE DEPENDENT    --- ;
 * --- VARIABLE (TPD) AND INDEPENDENT VARIABLES USED IN       --- ;
 * --- REGRESSION.  IT APPENDS TO THE DISCHARGE DATA ONE      --- ;
 * --- OBSERVATION PER MAREA AND DEMOGRAPHIC GROUP.           --- ;

 data   TEMP_2;
 set    OUTMSR.&OUTFILE_MEAS.(keep=KEY FIPSTCO T&PD. POPCAT SEXCAT RACECAT);

 if T&PD. in (0,1);
 if POPCAT in (1,2,3,4);

 %CTY2MA

 run;

 proc   Summary data=TEMP_2 NWAY;
 class  T&PD. MAREA POPCAT SEXCAT RACECAT;
 var    T&PD.;
 output out=TEMP_3 N=TCOUNT;
 run;

 proc   Sort data=TEMP_3;
 by     MAREA POPCAT SEXCAT RACECAT;
 run;

 /* RETAIN ONLY RECORDS WITH A VALID FIPS CODE */;

 data   TEMP1;
 merge  TEMP_3(in=X keep=MAREA POPCAT SEXCAT RACECAT TCOUNT T&PD.)
        QIPOP(keep=MAREA POPCAT SEXCAT RACECAT);
 by     MAREA POPCAT SEXCAT RACECAT;

 if X;

 if TCOUNT > 0 then PCOUNT = TCOUNT;
 else PCOUNT = 0;

 if PCOUNT = 0 then delete;
 
 run;

 data   TEMP1;
 length FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10 3;
 set    TEMP1;

 if SEXCAT in (2) then FEMALE = 1;
 else FEMALE = 0;

 array ARRY1{4} AGECAT1-AGECAT4;
 array ARRY2{4} FAGECAT1-FAGECAT4;

 do I = 1 TO 4;
    ARRY1(I) = 0; ARRY2(I) = 0;
 end;

 ARRY1(POPCAT) = 1;
 ARRY2(POPCAT) = FEMALE;

 array ARRY3{10} POVCAT1-POVCAT10;

 do I = 1 TO 10;
    ARRY3(I) = 0;
 end;

 PVIDX = put(MAREA,$POVCAT.);

 if PVIDX > 0 then ARRY3(PVIDX) = 1;

 run;

 
 data   TEMP1Y;
 set    TEMP1;

 ONE = 1;

 run;

 * -------------------------------------------------------------- ;
 * --- AGGREGATE POPULATION COUNTS BY STRATIFIERS             --- ;
 * -------------------------------------------------------------- ;

 proc   Summary data=TEMP1Y;
 class  MAREA POPCAT SEXCAT RACECAT;
 var    T&PD. ONE;
 output out=ADJ_&PD. SUM(T&PD. ONE)=T&PD. P&PD.;
 weight PCOUNT;
 run;

 data   ADJ_&PD.(keep=MAREA POPCAT SEXCAT RACECAT _TYPE_ T&PD. P&PD.);
 set    ADJ_&PD.;

 if _TYPE_ &TYPELVLA;

 run;

 proc Sort data=ADJ_&PD.;
     by MAREA POPCAT SEXCAT RACECAT;
 run; quit;

 proc   Datasets NOLIST;
 delete TEMP1 TEMP1Y TEMP_2 TEMP_3 TEMP_4;
 run;

 %MEND;


 %MOD3(APQ09);

/* MERGE THE ADJUSTED DENOMINATOR AND NUMERATOR FOR AREA PATIENT SAFETY INDICATORS. */
 
data TEMP2Y;
  set ADJ_APQ09;
  by MAREA POPCAT  SEXCAT RACECAT;
run;

  * -------------------------------------------------------------- ; 
  * --- PEDIATRIC QUALITY INDICATOR (PDI) NAMING CONVENTION:   --- ; 
  * --- THE FIRST LETTER IDENTIFIES THE PATIENT SAFETY         --- ; 
  * --- INDICATOR AS ONE OF THE FOLLOWING: 
                  (T) NUMERATOR ("TOP") - FROM PDI_ALL_MEASURES 
                  (P) POPULATION ("POP") - FROM PDI_ALL_MEASURES 
                  (A) ADJUSTED POPULATION 
                  (O) OBSERVED RATES 
  * --- THE SECOND LETTER IDENTIFIES THE PDI AS A PROVIDER (P) --- ; 
  * --- OR AN AREA (A) LEVEL INDICATOR.  THE                   --- ; 
  * --- NEXT TWO CHARACTERS ARE ALWAYS 'PD'. THE LAST TWO      --- ; 
  * --- DIGITS ARE THE INDICATOR NUMBER (WITHIN THAT SUBTYPE). --- ; 
  * -------------------------------------------------------------- ; 

 /* CALCULATE OBSERVED RATE AS SUM OF NUMERATOR / SUM OF ADJUSTED DENOMINATOR.*/
 data &OUTFILE_AREAOBS.;
 set TEMP2Y;

  array PPD2{1} PAPQ09;
  array TPD{1}  TAPQ09;
  array OPD{1}  OAPQ09;

 do J = 1 to 1;
    if TPD{J} GT 0 and PPD2{J} GT 0 then OPD{J} = TPD{J} / PPD2{J};
    else if PPD2{J} GT 0 then OPD{J} = 0;
 end;

label
 TAPQ09 = 'PQI 09 Low Birth Weight Rate (Numerator)'
 PAPQ09 = 'PQI 09 Low Birth Weight Rate (Population)'
 OAPQ09 = 'PQI 09 Low Birth Weight Rate (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL'
 ;

 drop J;

 run;

 proc Sort data=&OUTFILE_AREAOBS. OUT=OUTAOBS.&OUTFILE_AREAOBS.;
 by MAREA POPCAT SEXCAT RACECAT;
 run;

proc Datasets nolist;
  delete MAREA QIPOP QIPOP0 TEMP0 TEMP2Y
         ADJ_APQ09;
run; quit;
 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF AREA OBSERVED MEANS FILE ----------- ;
 * -------------------------------------------------------------- ;

 proc Contents data=OUTAOBS.&OUTFILE_AREAOBS. position;
 run;

 ***----- TO PRINT VARIABLE LABLES COMMENT (DELETE) "NOLABELS" FROM PROC MEANS STATEMENTS -------***;

proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (WHERE=(_TYPE_ in (8))) n nmiss min max sum nolabels;
  var TAPQ09 ;
   title  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR OVERALL NUMERATOR (SUM) WHEN _TYPE_=8';
run; quit;

proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (WHERE=(_TYPE_ in (8))) n nmiss min max sum nolabels;
  var PAPQ09;
   title  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR OVERALL DENOMINATOR (SUM) WHEN _TYPE_=8';
run; quit;

proc Means data=OUTAOBS.&OUTFILE_AREAOBS. (WHERE=(_TYPE_ in (8))) n nmiss min max mean nolabels;
   var OAPQ09 ;
   title  'SUMMARY OF PATIENT QUALITY AREA-LEVEL INDICATOR AVERAGE RATES(MEAN) WHEN _TYPE_=8';
run; quit;

 * -------------------------------------------------------------- ;
 * --- PRINT AREA OBSERVED MEANS FILE --------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT);

 proc  PRINT data=OUTAOBS.&OUTFILE_AREAOBS. label SPLIT='*';
 var   MAREA POPCAT SEXCAT RACECAT TA&PD. PA&PD. OA&PD. ;
 label MAREA    = "MAREA"
       POPCAT   = "POPCAT"
       SEXCAT   = "SEXCAT"
       RACECAT  = "RACECAT"
       TA&PD.   = "TA&PD.*(Numerator)"
       PA&PD.   = "PA&PD.*(Denominator)"
       OA&PD.   = "OA&PD.*(Observed)"
       ;
 format POPCAT POPCAT.   
        SEXCAT SEXCAT.
        RACECAT RACECAT.
        TA&PD. PA&PD. COMMA13.0
        OA&PD. 8.6
        ;
 title4 "Indicator &PD.: &TEXT";
 run;

 %MEND PRT;

 %PRT(PQ09,Low Birth Weight Rate);

 %END;

 %MEND PRT2;

 %PRT2; 

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TEXTAOBS. = 1  %THEN %DO;

 data _NULL_;
 set OUTAOBS.&OUTFILE_AREAOBS.;
 file PDAOBS lrecl=1000;
 if _N_=1 then do;
  
  put "MAREA"  "," "Age"  "," "Sex"  "," "Race"  "," "Type" ","
 "TAPQ09" "," 
 "PAPQ09" "," 
 "OAPQ09"  
;
end;

 put MAREA $5. "," POPCAT 3. "," SEXCAT 3. "," RACECAT 3.  "," _TYPE_ 2.  ","
 (TAPQ09) (7.0 ",")
 ","
 (PAPQ09) (13.2 ",")
 ","
 (OAPQ09) (12.10 ",")
 ;

 run;

 %END;

 %MEND TEXT;

 %TEXT;
