*============================ PROGRAM: PQI09_AREA_RISKADJ.SAS ============================;
*
*        Title:  AREA LEVEL RISK ADJUSTED RATES FOR AHRQ 
*                PEDIATRIC QUALITY INDICATOR 09
*
*  Description:
*        Calculates Risk-Adjusted and Smoothed Rates for Patient Safety
*        Indicators, adjusting for: SEX, AGE, DRG, MDC AND COMORBIDITY.
*        Variables created by the program: RAPDxx, LAPDxx, LAPDxx, SAPDxx, XAPDxx
*        Output stratified by AGE, SEXCAT AND POVCAT.
*
*        AHRQ QI VERSION V6.0.2 ICD-09-CM
*        VERSION DATE AUGUST 2017
*
*=========================================================================================;
* See the AHRQ_QI_ICD09_v6_Release_Notes.txt file for version change details.;

filename CONTROL 'c:\Pathname\PQI_09\Programs\PQI09_ALL_CONTROL.SAS'; *<===USER MUST modify;
%include CONTROL;


 %MACRO CTY2MA;
    %IF &MALEVL EQ 0 %THEN %DO;
        attrib MAREA length=$5
          label='FIPS STATE COUNTY CODE';
        MAREA = FIPSTCO;
    %END;
    %ELSE %IF &MALEVL EQ 1 %THEN %DO;
        attrib MAREA length=$5
          label='MODIFIED FIPS';
        MAREA = input(put(FIPSTCO,$M1AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 2 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 1999 METRO AREA';
        MAREA = input(put(FIPSTCO,$M2AREA.),$5.);
    %END;
    %ELSE %IF &MALEVL EQ 3 %THEN %DO;
        attrib MAREA length=$5
          label='OMB 2003 METRO AREA';
        MAREA = input(put(FIPSTCO,$M3AREA.),$5.);
    %END;
 %MEND;

 title2 'PROGRAM PQI09_AREA_RISKADJ - PART I';
 title3 'AHRQ PEDIATRIC QUALITY INDICATORS: CALCULATE RISK-ADJUSTED AREA RATES';

 * ---------------------------------------------------------------- ;
 * --- ADD POPULATION DENOMINATOR --------------------------------- ;
 * --- THIS STEP DETERMINES WHICH AREAS ARE INCLUDED IN THE     --- ;
 * --- OUTPUT FROM PROGRAM PQI09_AREA_OBSERVED.                 --- ;
 * ---------------------------------------------------------------- ;

 data   TEMP0;
 set    OUTMSR.&OUTFILE_MEAS.;

 %CTY2MA

 run;

 proc   Sort data=TEMP0 (keep=MAREA) out=MAREA nodupkey;
 by     MAREA;
 run;

 data QIPOP0;
    length FIPSTCO $5 SEXCAT POPCAT RACECAT 3 
           POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
           POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
           POP_2005 POP_2006 POP_2007 POP_2008 POP_2009 
           POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
           POP_2015 POP 8;

    infile POPFILE missover firstobs=2;

    input FIPSTCO SEXCAT POPCAT RACECAT 
          POP_1995 POP_1996 POP_1997 POP_1998 POP_1999
          POP_2000 POP_2001 POP_2002 POP_2003 POP_2004
          POP_2005 POP_2006 POP_2007 POP_2008 POP_2009
          POP_2010 POP_2011 POP_2012 POP_2013 POP_2014
          POP_2015;

    %CTY2MA

    POP = POP_&POPYEAR.;

    if POPCAT in (1,2,3,4);

 run;

 proc   Summary data=QIPOP0 nway;
 class  MAREA POPCAT SEXCAT RACECAT;
 var    POP;
 output out=QIPOP sum=;
 run;

 proc   Sort data=QIPOP;
 by     MAREA POPCAT SEXCAT RACECAT;
 run;

 data   QIPOP(keep=MAREA POPCAT SEXCAT RACECAT POP);
 merge  MAREA(in=X) QIPOP(in=Y);
 by     MAREA;

 if X and Y;

 run;

 * ----------------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATORS ADJUSTED RATES ----------------------- ;
 * ----------------------------------------------------------------------- ;
 * --- THIS STEP SELECTS THE OBSERVATIONS FROM THE PQI09_AREA_OBSERVED --- ;
 * --- PROGRAM OUTPUT FOR EACH PEDIATRIC QUALITY INDICATOR IN TURN.    --- ;
 * --- EACH ITERATION PASSES VARIABLES THAT CONTROL THE                --- ;
 * --- COVARIATES FOR THAT PEDIATRIC QUALITY INDICATOR:                --- ;
 * --- N - OBSERVATION NUMBER FROM THE MEANS AND COVAR FILES           --- ;
 * ---     ALSO IDENTIFIES THE FORMAT USED TO INDEX COVARIATES         --- ;
 * --- PD - THE PEDIATRIC QUALITY INDICATOR NAME WITHOUT THE           --- ;
 *          PREFIX (A)                                                 --- ;
 * ----------------------------------------------------------------------- ;

 %MACRO MOD3(N,PD);

 * --- THIS SET CREATES TEMP1 WHICH CONTAINS THE DEPENDENT    --- ;
 * --- VARIABLE (TPD) AND INDEPENDENT VARIABLES USED IN       --- ;
 * --- REGRESSION.  IT APPENDS TO THE DISCHARGE DATA ONE      --- ;
 * --- OBSERVATION PER MAREA AND DEMOGRAPHIC GROUP.           --- ;

 data   TEMP_2;
 set    OUTMSR.&OUTFILE_MEAS.(keep=KEY FIPSTCO T&PD. POPCAT SEXCAT RACECAT);

 if T&PD. in (0,1);
 if POPCAT in (1,2,3,4);

 %CTY2MA

 run;

 proc   Summary data=TEMP_2 nway;
 class  T&PD. MAREA POPCAT SEXCAT RACECAT;
 var    T&PD.;
 output out=TEMP_3 N=TCOUNT;
 run;

 proc   Sort data=TEMP_3;
 by     MAREA POPCAT SEXCAT RACECAT;
 run;

 /* RETAIN ONLY RECORDS WITH A VALID FIPS CODE */;

 data   TEMP1;
 merge  TEMP_3(in=X keep=MAREA POPCAT SEXCAT RACECAT TCOUNT T&PD.)
        QIPOP(keep=MAREA POPCAT SEXCAT RACECAT);
 by     MAREA POPCAT SEXCAT RACECAT;

 if X;

 if TCOUNT > 0 then PCOUNT = TCOUNT;
 else PCOUNT = 0;

 if PCOUNT = 0 then delete;
 
 run;

 data   TEMP1;
 length FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10 3;
 set    TEMP1;

 if SEXCAT in (2) then FEMALE = 1;
 else FEMALE = 0;

 array ARRY1{4} AGECAT1-AGECAT4;
 array ARRY2{4} FAGECAT1-FAGECAT4;

 do I = 1 TO 4;
    ARRY1(I) = 0; ARRY2(I) = 0;
 end;

 ARRY1(POPCAT) = 1;
 ARRY2(POPCAT) = FEMALE;

 array ARRY3{10} POVCAT1-POVCAT10;

 do I = 1 TO 10;
    ARRY3(I) = 0;
 end;

 PVIDX = put(MAREA,$POVCAT.);

 if PVIDX > 0 then ARRY3(PVIDX) = 1;

 run;

 * --- THIS DATA STEP READS THE REGRESSION COEFFICIENTS FOR EACH - ;
 * --- COVARIATE.                                              --- ;

 data   TEMP2(keep=INTERCEP FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
                   POVCAT1-POVCAT10  
                   _NAME_ _TYPE_ _LINK_ _LNLIKE_ _STATUS_);
 length INTERCEP FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10 _LNLIKE_ 8
        _NAME_ _TYPE_ _LINK_ $8 _STATUS_ $11;

 %IF &USE_SES=0 %THEN %DO ;
 infile COVAR MISSOVER LRECL=500;
 %END ;
 %ELSE %DO ;
 infile COVARSES MISSOVER LRECL=500;
 %END ;

 input  N INTERCEP FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10  
        _NAME_ _TYPE_ _LINK_ _LNLIKE_ _STATUS_;

 if N = &N.;

 run;

 * --- THIS PROC CALCULATES A PREDICTED INPATIENT QUALITY         - ;
 * --- INDICATOR FOR EACH OBSERVATION USING THE ACTUAL COVARIATES - ;
 * --- AND THE ESTIMATED COEFFICIENTS.                            - ;

 proc   SCORE data=TEMP1 SCORE=TEMP2 TYPE=PARMS out=TEMP1Y;
 var    FEMALE AGECAT1-AGECAT4 FAGECAT1-FAGECAT4
        POVCAT1-POVCAT10;
 run;

 %let dsid=%sysfunc(open(temp1y));
 %let dnum=%sysfunc(attrn(&dsid,nobs));
 %let drc=%sysfunc(close(&dsid));

 %if &dnum ne 0 %then %do;

 data   TEMP1Y;
 set    TEMP1Y;

 EHAT = EXP(MHAT)/(1 + EXP(MHAT));
 PHAT = EHAT * (1 - EHAT);
 ONE = 1;

 run;

 proc   Summary data=TEMP1Y;
 class  MAREA POPCAT SEXCAT RACECAT;
 var    T&PD. EHAT PHAT ONE;
 output out=R&PD. SUM(T&PD. EHAT PHAT ONE)=T&PD. EHAT PHAT P&PD.;
 weight PCOUNT;
 run;

 data   R&PD.(keep=MAREA POPCAT SEXCAT RACECAT _TYPE_
                   E&PD. R&PD. L&PD. U&PD. S&PD. X&PD.);
 set    R&PD.;

 if _TYPE_ &TYPELVLA;

 %IF &USE_SES=0 %THEN %DO ;
    %include MacLib(PQI09_Area_Sigvar_Array_v60.sas) ;
 %END ;
 %ELSE %DO ;
    %include MacLib(PQI09_Area_Sigvar_Array_SES_v60.sas) ;
 %END ;

 if &N. = 14 then SUB_N = 1;
 if &N. = 15 then SUB_N = 2;
 if &N. = 16 then SUB_N = 3;
 if &N. = 17 then SUB_N = 4;
 if &N. = 18 then SUB_N = 5;
 if &N. = 90 then SUB_N = 6;
 if &N. = 91 then SUB_N = 7;
 if &N. = 92 then SUB_N = 8;
 if &N. = 60 then SUB_N = 9;

 E&PD. = EHAT / P&PD.;
 THAT = T&PD. / P&PD.;

 if _TYPE_ in (0,8) then do;
    R&PD.   = (THAT / E&PD.) * ARRYA3(SUB_N);
    SE&PD.  = (ARRYA3(SUB_N) / E&PD.) * (1 / P&PD.) * SQRT(PHAT);
    VAR&PD. = SE&PD.**2;
    SN&PD.  = ARRYA2(SUB_N) / (ARRYA2(SUB_N) + VAR&PD.);
    S&PD.   = (R&PD. * SN&PD.) + ((1 -  SN&PD.) * ARRYA3(SUB_N));
    X&PD.   = SQRT(ARRYA2(SUB_N)- (SN&PD. * ARRYA2(SUB_N)));
 end;
 else do;
    R&PD.   = (THAT / E&PD.);
    SE&PD.  = (1 / E&PD.) * (1 / P&PD.) * SQRT(PHAT);
    S&PD.   = .;
    X&PD.   = .;
 end;

 L&PD.   = R&PD. - (1.96 * SE&PD.);
 if L&PD. < 0 then L&PD. = 0;
 U&PD.   = R&PD. + (1.96 * SE&PD.);

 if _TYPE_ in (0,8) then do; 
     if L&PD. > 1 then L&PD. = 1; 
    if U&PD. > 1 then U&PD. = 1;
    if R&PD. > 1 then R&PD. = 1;
 end;

 run;

 %end;
 %else %do;

 data   R&PD.;
  
    MAREA='';POPCAT=.;SEXCAT=.;RACECAT=.;_TYPE_=0;_FREQ_=0;E&PD=.;R&PD=.;L&PD=.;U&PD=.;P&PD=.;S&PD=.;X&PD=.;
    output;
 run;

 %end;

 proc Sort data=R&PD.;
   by MAREA POPCAT SEXCAT RACECAT;
 run; quit;


 %MEND;


 %MOD3(60,APQ09);

 * --- MERGES THE MAREA ADJUSTED RATES FOR EACH PEDIATRIC QUALITY - ;
 * --- INDICATOR.  PREFIX FOR THE ADJUSTED RATES IS R (Risk     --- ;
 * --- Adjusted).                                               --- ;

 data   RISKADJ;
 merge  RAPQ09(keep=MAREA POPCAT SEXCAT RACECAT EAPQ09 RAPQ09 LAPQ09 UAPQ09 SAPQ09 XAPQ09);
 by     MAREA POPCAT SEXCAT RACECAT;

 label
 EAPQ09 = 'PQI 09 Low Birth Weight Rate  (Expected)'
 RAPQ09 = 'PQI 09 Low Birth Weight Rate  (Risk Adj)'
 LAPQ09 = 'PQI 09 Low Birth Weight Rate  (Lower CL)'
 UAPQ09 = 'PQI 09 Low Birth Weight Rate  (Upper CL)'
 SAPQ09 = 'PQI 09 Low Birth Weight Rate  (Smoothed)'
 XAPQ09 = 'PQI 09 Low Birth Weight Rate  (Smthe SE)'
 ;

 run;

*==================================================================;
*  PART II:  MERGE AREA RATES FOR AHRQ PEDIATRIC QUALITY INDICATORS
*===================================================================;

 title2 'PROGRAM PQI09_AREA_RISKADJ -  PART II';
 title3 'AHRQ PEDIATRIC QUALITY INDICATORS:  AREA-LEVEL MERGED FILES';

 * ---------------------------------------------------------------- ;
 * --- PEDIATRIC QUALITY INDICATOR MERGED RATES                 --- ;
 * ---------------------------------------------------------------- ;

 data   OUTARSK.&OUTFILE_AREARISK.;
 merge  OUTAOBS.&OUTFILE_AREAOBS.(
             keep=MAREA POPCAT SEXCAT RACECAT _TYPE_ 
                   TAPQ09  
                   PAPQ09  
                   OAPQ09)
             RISKADJ(keep=MAREA POPCAT SEXCAT RACECAT
                          EAPQ09
                          RAPQ09
                          LAPQ09
                          UAPQ09
                          SAPQ09
                          XAPQ09);
 by     MAREA POPCAT SEXCAT RACECAT;

 array ARRY1{1} EAPQ09;
 array ARRY2{1} RAPQ09;
 array ARRY3{1} LAPQ09;
 array ARRY4{1} UAPQ09;
 array ARRY5{1} SAPQ09;
 array ARRY6{1} XAPQ09;
 array ARRY7{1} PAPQ09;

 do I = 1 TO 1;
   if ARRY7(I) <= 2 then do;
      ARRY1(I) = .; ARRY2(I) = .; ARRY3(I) = .; ARRY4(I) = .;
      ARRY5(I) = .; ARRY6(I) = .; 
   end;
 end;

 drop I;

  format EAPQ09
      LAPQ09
      OAPQ09
      RAPQ09
      SAPQ09
      UAPQ09
      XAPQ09 13.7
      TAPQ09
      PAPQ09 13.0;
 run;

 * ---------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF MAREA MERGED MEANS FILE            --- ;
 * ---------------------------------------------------------------- ;

 proc Contents data=OUTARSK.&OUTFILE_AREARISK. position;
 run;

 proc Means data=OUTARSK.&OUTFILE_AREARISK.(WHERE=(_TYPE_ in (8))) n nmiss min max mean sum nolabels;
 title4  'SUMMARY OF AREA-LEVEL RATES (_TYPE_=8)';
 run;

 * ---------------------------------------------------------------- ;
 * --- PRINT AREA MERGED MEANS FILE                             --- ;
 * ---------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT);

 proc   Print data=OUTARSK.&OUTFILE_AREARISK. label SPLIT='*';
 var    MAREA POPCAT SEXCAT RACECAT 
        TA&PD. PA&PD. OA&PD. EA&PD. RA&PD. LA&PD. UA&PD. SA&PD. XA&PD.;
 label MAREA    = "MAREA"
       POPCAT   = "POPCAT"
       SEXCAT   = "SEXCAT"
       RACECAT  = "RACECAT"
       TA&PD. = "TA&PD.*(Numerator)"
       PA&PD. = "PA&PD.*(Denominator)"
       OA&PD. = "OA&PD.*(Observed)"
       EA&PD. = "EA&PD.*(Expected)"
       RA&PD. = "RA&PD.*(Risk Adj)"
       LA&PD. = "LA&PD.*(Lower CL)"
       UA&PD. = "UA&PD.*(Upper CL)"
       SA&PD. = "SA&PD.*(Smoothed)"
       XA&PD. = "XA&PD.*(Smthe SE)"
       ;
 FORMAT POPCAT POPCAT.   
        SEXCAT SEXCAT.
        RACECAT RACECAT.
     TA&PD. PA&PD. COMMA13.0
        OA&PD. EA&PD. RA&PD. LA&PD. UA&PD. SA&PD. XA&PD. 8.6;

 title4 "FINAL OUTPUT";
 title5 "Indicator &PD.: &TEXT";
 run;

 %MEND PRT;


 %PRT(PQ09,Low Birth Weight Rate);

 %END;

 %MEND PRT2 ;

 %PRT2;

 * ---------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO TEXT FILE                   --- ;
 * ---------------------------------------------------------------- ;

 %MACRO TEXT;

 %IF &TEXTARSK. = 1  %THEN %DO;

 data _NULL_;
 set OUTARSK.&OUTFILE_AREARISK.;
 FILE PDARSK LRECL=2000;
 if _N_=1 then do;

 put "MAREA" "," "Age"  "," "Sex"  "," "Race"  ","  "Type" ","
 "TAPQ09" "," 
 "PAPQ09" "," 
 "OAPQ09" "," 
 "EAPQ09" "," 
 "RAPQ09" "," 
 "LAPQ09" "," 
 "UAPQ09" "," 
 "SAPQ09" "," 
 "XAPQ09"  
 ;
end;

 put MAREA  $5. "," POPCAT 3. "," SEXCAT 3. "," RACECAT 3. "," _TYPE_ 2. ","
 (TAPQ09) (7.0 ",")
  ","
 (PAPQ09) (13.2 ",")
 ","
 (OAPQ09) (12.10 ",")
 ","
 (EAPQ09) (12.10 ",")
 ","
 (RAPQ09) (12.10 ",")
 ","
 (LAPQ09) (12.10 ",")
 ","
 (UAPQ09) (12.10 ",")
 ","
 (SAPQ09) (12.10 ",")
 ","
 (XAPQ09) (12.10 ",")
 ;
 run;


 %END;

 %MEND TEXT;

 %TEXT;
